
-------
Support
-------

Please consider the following ways to reach out to the community and the developers:

* To **discuss** with other PyPSA users, organise projects, share news, and get in touch with the community you can use the `Discord server <https://discord.gg/AnuJBk23FU>`_.
* For **bugs and feature requests**, please use the `issue tracker <https://github.com/PyPSA/PyPSA/issues>`_.
* We strongly welcome anyone interested in providing **contributions** to this project. If you have any ideas, suggestions or encounter problems, feel invited to file issues or make pull requests on `Github <https://github.com/PyPSA/PyPSA>`_.

.. note::
    All questions benefit from being accompanied by a minimal working example (MWE) that illustrates the problem or question,
    and by sharing which approaches you have already tried. See `troubleshooting <https://pypsa.org/doc/contributing/troubleshooting.html>`_ for more information on MWEs.
